@@ -19,24 +19,19 @@
  */
 
 #include "core/kmixdevicemanager.h"
-#include <kdebug.h>
 
-#ifdef X_KMIX_KF5_BUILD
 #ifdef __GNUC__
 #warning KMix KF5 build does not support hotplugging yet
 #endif
-#endif
 
 #include <iostream>
 
 #include <QRegExp>
 #include <QString>
 
-#ifndef X_KMIX_KF5_BUILD
-#include <solid/device.h>
-#include <solid/devicenotifier.h>
-#include <solid/audiointerface.h>
-#endif
+// #include <solid/device.h>
+// #include <solid/devicenotifier.h>
+// #include <solid/audiointerface.h>
 
 KMixDeviceManager* KMixDeviceManager::s_KMixDeviceManager = 0;
 
@@ -58,20 +53,16 @@ KMixDeviceManager* KMixDeviceManager::instance()
 
 void KMixDeviceManager::initHotplug()
 {
-#ifndef X_KMIX_KF5_BUILD
-	connect (Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)), SLOT(pluggedSlot(QString)) );
-    connect (Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)), SLOT(unpluggedSlot(QString)) );
-#endif
+//     connect (Solid::DeviceNotifier::instance(), SIGNAL(deviceAdded(QString)), SLOT(pluggedSlot(QString)) );
+//     connect (Solid::DeviceNotifier::instance(), SIGNAL(deviceRemoved(QString)), SLOT(unpluggedSlot(QString)) );
 }
 
 QString KMixDeviceManager::getUDI_ALSA(int num)
 {
-#ifdef X_KMIX_KF5_BUILD
-	QString udi("hw%i");
-	udi.arg(num);
-	return udi;
-#else
-	QList<Solid::Device> dl = Solid::Device::listFromType(Solid::DeviceInterface::AudioInterface);
+	return (QString("hw%1").arg(num));
+
+#if 0
+        QList<Solid::Device> dl = Solid::Device::listFromType(Solid::DeviceInterface::AudioInterface);
 
 	QString numString;
 	numString.setNum(num);
@@ -134,15 +125,15 @@ QString KMixDeviceManager::getUDI_ALSA(int num)
 		}
 	} // foreach
 	return udi;
-#endif
+#endif // 0
 }
 
 QString KMixDeviceManager::getUDI_OSS(const QString& devname)
 {
-#ifdef X_KMIX_KF5_BUILD
 	QString udi(devname);
 	return udi;
-#else
+
+#if 0
     QList<Solid::Device> dl = Solid::Device::listFromType(Solid::DeviceInterface::AudioInterface);
 
     bool found = false;
@@ -170,15 +161,15 @@ QString KMixDeviceManager::getUDI_OSS(const QString& devname)
         if ( found) break;
     } // foreach
     return udi;
-#endif
+#endif // 0
 }
 
 
-void KMixDeviceManager::pluggedSlot(const QString& udi) {
-#ifdef X_KMIX_KF5_BUILD
-return;
-#else
+void KMixDeviceManager::pluggedSlot(const QString& udi)
+{
+    return;
 
+#if 0
 //   std::cout << "Plugged udi='" <<  udi.toUtf8().data() << "'\n";
    Solid::Device device(udi);
    Solid::AudioInterface *audiohw = device.as<Solid::AudioInterface>();
@@ -205,11 +196,11 @@ return;
                 }
                 break;
            default:
-               kError(67100) <<  "Plugged UNKNOWN Audio device (ignored)";
+               qCCritical(KMIX_LOG) <<  "Plugged UNKNOWN Audio device (ignored)";
                break;
        }
     }
-#endif
+#endif // 0
 }
 
 
